@@ -5,7 +5,7 @@
 #include "resolver.h"
 #include "modfile.h"
 
-#include <src/audio_typefind.hh>
+#include "src/audio/audio-typefind.hh"
 
 TagLib::File * MODFileTypeResolver::createFile (const char                        *filename,
                                                 bool                               read_properties,
