@@ -3,15 +3,15 @@
 #endif //HAVE_CONFIG_H
 
 #include <glibmm.h>
-#include <taglib/fileref.h>
-#include <taglib/taglib.h>
-#include <taglib/fileref.h>
-#include <taglib/tfile.h>
-#include <taglib/tag.h>
-#include <taglib/oggfile.h>
-#include <taglib/vorbisfile.h>
-#include <taglib/vorbisproperties.h>
-#include <taglib/xiphcomment.h>
+#include <fileref.h>
+#include <taglib.h>
+#include <fileref.h>
+#include <tfile.h>
+#include <tag.h>
+#include <oggfile.h>
+#include <vorbisfile.h>
+#include <vorbisproperties.h>
+#include <xiphcomment.h>
 
 #include "bmp/types/types-basic.hh"
 #include "bmp/types/types-library.hh"
