@@ -116,6 +116,8 @@ namespace Bmp
     , m_played_seconds        (0)
     , m_seeking               (false)
     {
+	  m_message_queue = g_async_queue_new ();
+
       for (int n = 0; n < SPECT_BANDS; ++n)
       {
         m_spectrum.push_back (0);
@@ -144,6 +146,7 @@ namespace Bmp
     {
       request_status (PLAYSTATUS_STOPPED);
       destroy_bins ();
+      g_async_queue_unref (m_message_queue);
     }
 
     GstElement*
@@ -411,7 +414,6 @@ namespace Bmp
               if (m_video_pipe)
               {
                 g_object_set (m_video_pipe->operator[]("filesrc"), "location", filename_from_uri (property_stream_.get_value()).c_str(), NULL);
-                g_object_set (m_video_pipe->operator[]("videosink1"), "force-aspect-ratio", gboolean (TRUE), NULL);
                 pipeline_configure (PIPELINE_VIDEO);
               }
               else
@@ -513,7 +515,7 @@ namespace Bmp
     }
 
     void
-    Play::switch_stream (ustring const& stream,
+    Play::switch_stream_real (ustring const& stream,
                          ustring const& type)
     {
       m_stream_lock.lock ();
@@ -525,8 +527,30 @@ namespace Bmp
       m_stream_lock.unlock ();
     }
 
+    void
+    Play::switch_stream (ustring const& stream,
+                         ustring const& type)
+    {
+	  Audio::Message message;
+	  message.stream = stream;
+	  message.type = type;
+          message.id = 1;
+
+	  push_message (message);
+	}		
+
     void
     Play::request_status (BmpPlaystatus status)
+    {
+	Audio::Message message;
+	message.status = status;
+	message.id = 0;
+
+	push_message (message);
+    } 
+
+    void
+    Play::request_status_real (BmpPlaystatus status)
     {
       m_state_lock.lock ();
 
@@ -1336,4 +1360,34 @@ namespace Bmp
     {
       return m_metadata;
     }
-};
+
+    void
+    Play::process_queue ()
+    {
+	    while (g_async_queue_length (m_message_queue) > 0)
+	    {
+	            gpointer data = g_async_queue_pop (m_message_queue);
+		    Audio::Message *message = reinterpret_cast<Audio::Message*>(data);
+
+		    switch (message->id)
+		    {
+			    case 0: /* FIXME: Enums */
+				    request_status_real (message->status);
+				    break;
+
+			    case 1:
+				    switch_stream_real (message->stream, message->type);
+				    break;
+		    }
+
+		    delete message;
+	    }
+    }
+
+    void
+    Play::push_message (Audio::Message const& message)
+    {
+	    g_async_queue_push (m_message_queue, (gpointer)(new Audio::Message (message)));
+	    process_queue ();
+    }
+}
