@@ -92,7 +92,7 @@ namespace Bmp
       xmlCreateIntSubset (doc,
                           BAD_CAST "bkm",
                           NULL,
-                          BAD_CAST "http://bmpx.beep-media-player.org/dtd/bookmarks-1.dtd" );
+                          BAD_CAST "http://bmpx.backtrace.info/dtd/bookmarks-1.dtd" );
 
       std::string filename = build_filename (BMP_PATH_DATA_DIR, "bookmarks.xml");
       xmlThrDefIndentTreeOutput (1);
@@ -123,7 +123,7 @@ namespace Bmp
         xo = xpath_query
               (doc,
                BAD_CAST "//bmp:bookmark",
-               BAD_CAST "bmp=http://beep-media-player.org/ns/0/");
+               BAD_CAST "bmp=http://bmpx.backtrace.info/ns/0/");
 
         nv = xo->nodesetval;
 
