@@ -718,15 +718,28 @@ namespace Bmp
            bool               is_removed,
            bool               is_added)
       {
-        if (!m_context->device_query_capability (udi, "volume"))
-        {
-          debug ("hal", "'%s' does not have 'volume' capability!");
-          return;
-        }
+        try{
+		if (!m_context->device_query_capability (udi, "volume"))
+		{
+		  debug ("hal", "'%s' does not have 'volume' capability!");
+		  return;
+		}
+	    }
+	catch (Hal::Device::UnableToProbeDeviceError & cxe)
+	    {
+		  return;
+ 	    }
 
-        Hal::RefPtr<Hal::Volume> volume = Hal::Volume::create_from_udi (m_context, udi);
-        debug ("hal", "'%s' is %s", udi.c_str(), (volume->is_mounted()?"mounted":"not mounted"));
-        process_udi (udi);
+	try{
+		Hal::RefPtr<Hal::Volume> volume = Hal::Volume::create_from_udi (m_context, udi);
+		debug ("hal", "'%s' is %s", udi.c_str(), (volume->is_mounted()?"mounted":"not mounted"));
+		process_udi (udi);
+	   
+ 	   }
+	catch (Hal::Device::DeviceDoesNotExistError & cxe)
+	   {
+		return;
+	   }
       }
 
       HAL::SignalVolume&
