@@ -851,7 +851,7 @@ namespace Bmp
       xmlCreateIntSubset (doc,
                           BAD_CAST "lqm",
                           NULL,
-                          BAD_CAST "http://bmpx.beep-media-player.org/dtd/lqm-2.dtd" );
+                          BAD_CAST "http://bmpx.backtrace.info/dtd/lqm-2.dtd" );
 
       xmlThrDefIndentTreeOutput (1);
       xmlKeepBlanksDefault (0);
