@@ -1938,10 +1938,10 @@ namespace Bmp
                                      % attrinfo[ATTRIBUTE_LOCATION].id).str());
 #endif //HAVE_HAL
 
-      try{
+      if(m_db->table_exists("track_v"))
+      {
         m_db->exec_sql ("DROP VIEW track_v");
-        }
-      catch (...) {}
+      }
 
       m_db->exec_sql
 
