@@ -41,6 +41,7 @@
 #include <glibmm/markup.h>
 #include <iostream>
 #include <fstream>
+#include <cstring>
 
 #include "paths.hh"
 #include "util.hh"
@@ -53,7 +54,6 @@
 #include "minisoup.hh"
 
 using namespace Glib;
-using namespace Gtk;
 
 namespace
 {
@@ -515,73 +515,66 @@ namespace Bmp
       if (name == "opml") 
       {
         SET_STATE(E_OPML);
-        return;
       }
 
       if (name == "head") 
       {
         SET_STATE(E_HEAD);
-        return;
       }
 
       if (name == "body") 
       {
         SET_STATE(E_BODY);
-        return;
       }
 
       if (name == "outline") 
       {
         SET_STATE(E_OUTLINE);
 
-        if (attributes.find ("xmlUrl") != attributes.end())
-        {
-          try{
-              Podcast cast; 
-              cast.uuid = attributes.find ("id")->second;
-              cast.podcast["source"] = attributes.find ("xmlUrl")->second;
+        try{
+          if (attributes.find ("xmlUrl") != attributes.end())
+          {
+                Podcast cast; 
+                cast.uuid = attributes.find ("id")->second;
+                cast.podcast["source"] = attributes.find ("xmlUrl")->second;
 
-              if( !cast.uuid.empty() && !cast.podcast["source"].empty())
-              {
-                m_manager.podcast_load (cast);
-                if (attributes.count ("lastPollTime") != 0) 
+                if( !cast.uuid.empty() && !cast.podcast["source"].empty())
                 {
-                  cast.attributes["last-poll-time"] = attributes.find ("lastPollTime")->second;
+                  m_manager.podcast_load (cast);
+                  if (attributes.count ("lastPollTime") != 0) 
+                  {
+                    cast.attributes["last-poll-time"] = attributes.find ("lastPollTime")->second;
+                  }
+                  m_casts.insert (std::make_pair (cast.podcast["source"], cast)); 
                 }
-                m_casts.insert (std::make_pair (cast.podcast["source"], cast)); 
-              }
-            }
-          catch (Bmp::PodcastV2::ParsingError & cxe) {}
+          }
         }
-        return;
+        catch (Bmp::PodcastV2::ParsingError & cxe) {}
+        catch (std::exception & cxe) {}
       }
     }
 
     void OPMLParser::on_end_element    (Markup::ParseContext    & context,
                                         ustring            const& name)
-	  {
+	{
       if (name == "opml") 
       {
         CLEAR_STATE(E_OPML);
-        return;
       }
 
       if (name == "head") 
       {
         CLEAR_STATE(E_HEAD);
-        return;
       }
 
       if (name == "body") 
       {
         CLEAR_STATE(E_BODY);
-        return;
       }
 
       if (name == "outline") 
       {
         CLEAR_STATE(E_OUTLINE);
-        return;
       }
     }
   }
