@@ -992,6 +992,8 @@ namespace Bmp
   void
   Preferences::setup_audio_widgets ()
   {
+    audio_system_cbox_ids.resize(16);
+ 
     m_ref_xml->get_widget ("cbox_video_out", m_cbox_video_out);
 
     CellRendererText * cell;
@@ -1003,10 +1005,12 @@ namespace Bmp
     m_cbox_audio_system->set_model (m_list_store_audio_systems);
 
     std::string sink = mcs->key_get<std::string> ("audio", "sink");
+    int cbox_counter = 0;
     for (unsigned int n = 0; n < G_N_ELEMENTS (audiosystems); n++)
     {
           if (test_element (audiosystems[n].name))
           {
+ 		audio_system_cbox_ids[n] = cbox_counter++;
                 m_sinks.insert (audiosystems[n].name);
                 TreeIter iter = m_list_store_audio_systems->append ();
                 (*iter)[audio_system_columns.description] = audiosystems[n].description;
@@ -1224,7 +1228,11 @@ namespace Bmp
         break;
       }
     }
-    m_cbox_audio_system->set_active (x);
+
+    if( x == NONE_SINK )
+	x = SINK_AUTO; // we fallback to autoaudiosink if garbage or unavailable output is in the config file
+	
+    m_cbox_audio_system->set_active (audio_system_cbox_ids[x]);
   
     if( x != NONE_SINK )
     {
