@@ -1,5 +1,5 @@
 /*  BMP - The Dumb Music Player
- *  Copyright (C) 2003-2006 BMP Project
+ *  Copyright (C) 2003-2006-2007 BMP Project
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -32,51 +32,87 @@
 
 #include <boost/format.hpp>
 
+#include "x_vfs.hh"
 #include "xml.hh"
 #include "util.hh"
-#include "uri++.hh"
+#include "uri.hh"
 #include "stock.hh"
 #include "paths.hh"
-#include "main.hh"
-#include "neon++/request.hh"
+#include "ui-tools.hh"
+#include "minisoup.hh"
+using namespace Glib;
+using namespace Gtk;
 
-#include "x_bookmarks.hh"
-#include "x_vfs.hh"
-
-#include "ui_toolbox.hh"
+#include "radio-directory-types.hh"
 #include "streams-icecast.hh"
 
-namespace
-{
-    static char* icecast_headers[] =
-    {
-      N_("Stream Name"),
-      N_("Bitrate"),
-      N_("Stream Genre"),
-    };
-}
-
 namespace Bmp
 {
-  namespace Streams
+  namespace RadioDirectory
   {
+    class IcecastParser
+        : public Glib::Markup::Parser
+    {
+      public:
+
+        IcecastParser (StreamListT & entries);
+        virtual ~IcecastParser ();
+
+        void check_sanity ();
+
+      protected:
+
+        virtual void
+        on_start_element  (Glib::Markup::ParseContext& context,
+                           Glib::ustring const& elementname,
+                           AttributeMap const& attributes);
+
+        virtual void
+        on_end_element (Glib::Markup::ParseContext& context,
+                        Glib::ustring const& elementname);
+
+        virtual void
+        on_text (Glib::Markup::ParseContext& context,
+                 Glib::ustring const& text);
+      private:
+
+        StreamListT & m_entries;
 
 #define STATE(e) ((state & e) != 0)
 #define SET_STATE(e) ((state |= e))
 #define CLEAR_STATE(e) ((state &= ~ e))
 
+        enum Element
+        {
+          E_NONE         = 0,
+          E_DIRECTORY    = 1 << 0,
+          E_ENTRY        = 1 << 1,
+          E_SERVER_NAME  = 1 << 2,
+          E_LISTEN_URL   = 1 << 3,
+          E_SERVER_TYPE  = 1 << 4,
+          E_BITRATE      = 1 << 5,
+          E_CHANNELS     = 1 << 6,
+          E_SAMPLERATE   = 1 << 7,
+          E_GENRE        = 1 << 8,
+          E_CURRENT_SONG = 1 << 9,
+        };
+
+        StreamInfo entry;
+        int state;
+      };
+
       void
       IcecastParser::check_sanity  ()
       {
         if (state)
-          {
-            g_warning (G_STRLOC ": State should be 0, but is %d", state);
-          }
+        {
+          g_warning (G_STRLOC ": State should be 0, but is %d", state);
+        }
       }
 
-      IcecastParser::IcecastParser (VIcecastEntries & entries) 
-        : m_entries (entries),
-          state     (0)
+      IcecastParser::IcecastParser (StreamListT & entries) 
+      : m_entries (entries)
+      , state     (0)
       {
       }
 
@@ -98,7 +134,7 @@ namespace Bmp
         if (name == "entry")
         {
           SET_STATE(E_ENTRY);
-          entry = IcecastEntry ();
+          entry = StreamInfo ();
           return;
         }
 
@@ -165,7 +201,6 @@ namespace Bmp
         {
           CLEAR_STATE(E_ENTRY);
           m_entries.push_back (entry); 
-          while (gtk_events_pending ()) gtk_main_iteration();
           return;
         }
 
@@ -216,185 +251,112 @@ namespace Bmp
           CLEAR_STATE(E_CURRENT_SONG);
           return;
         }
-
       }
 
       void
-      IcecastParser::on_text       (Glib::Markup::ParseContext& context,
-                                    Glib::ustring const&  text)
+      IcecastParser::on_text  (Glib::Markup::ParseContext& context,
+                               Glib::ustring const&  text)
       {
         if (!STATE(E_ENTRY))
           return;
 
         if (STATE(E_SERVER_NAME))
-          {
-            entry.server_name = text;
-            return;
-          }
+        {
+          entry.name = text;
+          return;
+        }
 
         if (STATE(E_LISTEN_URL))
-          {
-            entry.listen_url = text;
-            return;
-          }
+        {
+          entry.uri = text;
+          return;
+        }
 
         if (STATE(E_SERVER_TYPE))
-          {
-            entry.server_type = text;
-            return;
-          }
+        {
+          //entry.server_type = text;
+          return;
+        }
 
         if (STATE(E_GENRE))
-          {
-            entry.genre = text;
-            return;
-          }
+        {
+          entry.genre = text;
+          return;
+        }
 
         if (STATE(E_CHANNELS))
-          {
-            entry.channels = g_ascii_strtoull (text.c_str(), NULL, 10); 
-            return;
-          }
+        {
+          //entry.channels = g_ascii_strtoull (text.c_str(), NULL, 10); 
+          return;
+        }
 
         if (STATE(E_SAMPLERATE))
-          {
-            entry.samplerate = g_ascii_strtoull (text.c_str(), NULL, 10); 
-            return;
-          }
+        {
+          //entry.samplerate = g_ascii_strtoull (text.c_str(), NULL, 10); 
+          return;
+        }
 
         if (STATE(E_BITRATE))
-          {
-            entry.bitrate = g_ascii_strtoull (text.c_str(), NULL, 10); 
-            return;
-          }
+        {
+          entry.bitrate = g_ascii_strtoull (text.c_str(), NULL, 10); 
+          return;
+        }
+
+        if (STATE(E_CURRENT_SONG))
+        {
+          entry.current += text;
+          return;
+        }
       }
     
       void
-      Icecast::refresh ()
+      Icecast::refresh_callback (char const* data, guint size, guint code)
       {
-        using namespace Gtk;
-        using namespace Glib;
-
-        Neon::Request r ("dir.xiph.org", "/yp.xml");
-        r.set_check_server (false);
+        if (code != 200)
+        {
+          BaseData.Request.clear();
+          Signals.Stop.emit ();
+          return;
+        }
 
         std::string response;
+        response.append (data, size); 
 
-        if (r.dispatch () != NE_OK)
-          return;
-
-        r >> response;
-
-        m_streams->clear ();
-        VIcecastEntries entries;
-        try
-          {
+        StreamListT entries;
+        try{
             IcecastParser parser (entries);
             Markup::ParseContext context (parser);
             context.parse (response);
             context.end_parse ();
             parser.check_sanity ();
-          }
+        }
         catch (ConvertError& cxe)
-          {
-            return; 
-          }
+        {
+          return; 
+        }
         catch (MarkupError& cxe)
-          {
-            return;
-          }
-        catch (...) {}
+        {
+          return;
+        }
 
-        for (VIcecastEntries::const_iterator i = entries.begin() ;  i != entries.end() ; ++i) 
-          {
-            IcecastEntry const& entry (*i);
-
-            TreeModel::iterator m_iter = m_streams->append ();
-
-            (*m_iter)[columns.genre]       = entry.genre;
-            (*m_iter)[columns.bitrate]     = entry.bitrate;
-            (*m_iter)[columns.name]        = entry.server_name;
-            (*m_iter)[columns.uri]         = entry.listen_url;
-          }
-       while (gtk_events_pending ()) gtk_main_iteration();
-      }
-
-      bool
-      Icecast::visible_func (Gtk::TreeModel::iterator const& m_iter)
-      {
-        if (!m_filter.length ())
-          return true;
-
-        Glib::ustring name ((*m_iter)[columns.name]);
-        Glib::ustring genre ((*m_iter)[columns.genre]);
-        Glib::ustring needle (m_filter.casefold ());
-
-        name.casefold();
-        genre.casefold();
-
-        return ((Util::match_keys (name, needle)) || (Util::match_keys (genre, needle)));
+        set_stream_list (entries);
+        Signals.Stop.emit ();
       }
 
       void
-      Icecast::filter (Glib::ustring const& filter)
+      Icecast::refresh ()
       {
-        m_filter = filter;
-        m_filtered->refilter ();
-      }
-
-      void
-      Icecast::column_clicked (int column)
-      {
-        Gtk::SortType sort_type, sort_type_new;
-        int           sort_id;
-
-        m_streams->get_sort_column_id (sort_id, sort_type);
-
-        if ((sort_id >= 0) && (sort_id != column))
-          {
-            get_column (sort_id)->set_sort_indicator (false);
-          }
-
-        if (sort_id >= 0)
-          sort_type_new = (sort_type == Gtk::SORT_ASCENDING) ? Gtk::SORT_DESCENDING : Gtk::SORT_ASCENDING;
-        else
-          sort_type_new = Gtk::SORT_ASCENDING;
-
-        m_streams->set_sort_column_id (column, sort_type_new);
-        get_column (column)->set_sort_indicator (true);
-        get_column (column)->set_sort_order (sort_type_new);
-      }
-
-      void 
-      Icecast::get_stream (Glib::ustring& title, Glib::ustring& uri)
-      {
-        Gtk::TreeModel::iterator m_iter = get_selection()->get_selected ();
-        uri   = (*m_iter)[columns.uri];
-        title = (*m_iter)[columns.name];
+        BaseData.Streams->clear ();
+        Signals.Start.emit ();
+        BaseData.Request->run ();
       }
 
       Icecast::Icecast (BaseObjectType                       * obj,
                         Glib::RefPtr<Gnome::Glade::Xml> const& xml)
-
-          : Gtk::TreeView (obj),
-            m_streams     (Gtk::ListStore::create (columns)),
-            m_filtered    (Gtk::TreeModelFilter::create (m_streams))
+      : ViewBase (obj, xml)
       {
-        m_filtered->set_visible_func (sigc::mem_fun (this, &Bmp::Streams::Icecast::visible_func));
-
-        for (unsigned int n = 0; n < G_N_ELEMENTS (icecast_headers); n++)
-        {
-          Gtk::CellRendererText *cell;
-          cell = Gtk::manage (new Gtk::CellRendererText());
-          append_column (_(icecast_headers[n]), *cell);
-          get_column (n)->add_attribute (*cell, "text", n);
-          get_column (n)->set_resizable (true);
-          get_column (n)->signal_clicked ().connect
-                    (sigc::bind (sigc::mem_fun (this, &Bmp::Streams::Icecast::column_clicked),n));
-        }
-        get_selection()->set_mode (Gtk::SELECTION_SINGLE);
-        set_headers_clickable (true);
-        set_model (m_filtered);
+        BaseData.Request = Soup::Request::create ("http://dir.xiph.org/yp.xml");
+        BaseData.Request->request_callback().connect (sigc::mem_fun (*this, &Icecast::refresh_callback));
       }
   }
 };
