@@ -989,21 +989,22 @@ namespace Bmp
       m_pb_playing = Gdk::Pixbuf::create_from_file (build_filename (BMP_IMAGE_DIR_STOCK, "play.png"));
 
       struct {
+
         char const*             title;
         double                  xalign;
         Renderer                r;
         int                     column;
-        int                     width;
         Pango::EllipsizeMode    ellipsize;
+
       } cells[] = {
-          { " ",              0.5,   R_PIXBUF,   COLUMN_PLAYING,    0,      Pango::ELLIPSIZE_NONE   },
-          { " ",              0.5,   R_TOGGLE,   COLUMN_ACTIVE,     0,      Pango::ELLIPSIZE_NONE   },
-          { N_("Title"),      0.0,   R_TEXT,     COLUMN_TITLE,      290,    Pango::ELLIPSIZE_END    },
-          { N_("Artist"),     0.0,   R_TEXT,     COLUMN_ARTIST,     160,    Pango::ELLIPSIZE_END    },
-          { N_("Album"),      0.0,   R_TEXT,     COLUMN_ALBUM,      160,    Pango::ELLIPSIZE_END    },
-          { N_("Track"),      1.0,   R_TEXT,     COLUMN_TRACK,      0,      Pango::ELLIPSIZE_NONE   },
-          { N_("Length"),     0.5,   R_TEXT,     COLUMN_TIME,       0,      Pango::ELLIPSIZE_NONE   },
-          { N_("Genre"),      0.0,   R_TEXT,     COLUMN_GENRE,      0,      Pango::ELLIPSIZE_NONE   },
+          { " ",              0.5,   R_PIXBUF,   COLUMN_PLAYING,    Pango::ELLIPSIZE_NONE   },
+          { " ",              0.5,   R_TOGGLE,   COLUMN_ACTIVE,     Pango::ELLIPSIZE_NONE   },
+          { N_("Title"),      0.0,   R_TEXT,     COLUMN_TITLE,      Pango::ELLIPSIZE_END    },
+          { N_("Artist"),     0.0,   R_TEXT,     COLUMN_ARTIST,     Pango::ELLIPSIZE_END    },
+          { N_("Album"),      0.0,   R_TEXT,     COLUMN_ALBUM,      Pango::ELLIPSIZE_END    },
+          { N_("Track"),      1.0,   R_TEXT,     COLUMN_TRACK,      Pango::ELLIPSIZE_NONE   },
+          { N_("Length"),     0.5,   R_TEXT,     COLUMN_TIME,       Pango::ELLIPSIZE_NONE   },
+          { N_("Genre"),      0.0,   R_TEXT,     COLUMN_GENRE,      Pango::ELLIPSIZE_NONE   },
       };
 
       for (unsigned int n = 0 ; n < G_N_ELEMENTS (cells); ++n)
@@ -1049,7 +1050,6 @@ namespace Bmp
         }
 
         append_column (*c);
-        if( cells[n].width != 0) c->set_min_width (cells[n].width);
         c->set_cell_data_func (*r, (sigc::bind (sigc::mem_fun (*this, &Bmp::Playlist_V::cell_data_func), cells[n].column, cells[n].r)));
       }
 
