@@ -1486,15 +1486,12 @@ namespace Bmp
 
       if( playback )
       {
-        TreeIter iter = mListStore->get_iter (path_o);
-        if (iter)
-        {
+        // deselect the list if playback is true because it's probably
+        // likely that the user wants what they're adding. --nenolod
+        get_selection()->unselect_all();
+        clear_current_iter ();
+        if (mListStore->get_iter (path_o))
           assign_current_iter (mListStore->get_iter (path_o));
-        }
-        else
-        {
-          playback = false;
-        }
       }
 
       mSignals.RecheckCaps.emit ();
