@@ -1,5 +1,5 @@
 //  BMP
-//  Copyright (C) 2003-2007 http://beep-media-player.org 
+//  Copyright (C) 2003-2008 http://bmpx.baxcktrace.info
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License Version 2
@@ -81,6 +81,9 @@ using Bmp::URI;
 #define POD_ACTION_COPY_RSS_LINK    "pod-action-copy-rss-link"
 #define POD_ACTION_COPY_WEB_LINK    "pod-action-copy-web-link"
 #define POD_ACTION_EXPORT_FEEDLIST  "pod-action-export-feedlist"
+#define POD_ACTION_SORT_BY  	    "pod-action-sort-by"
+#define POD_ACTION_SORT_BY_NAME     "pod-action-sort-by-name"
+#define POD_ACTION_SORT_BY_DATE     "pod-action-sort-by-date"
 
 namespace
 {
@@ -115,6 +118,11 @@ namespace
   "     <menuitem action='" POD_ACTION_EXPORT_FEEDLIST "'/>"
   "     <separator name='podcasts-3'/>"
   "     <menuitem action='" POD_ACTION_UPD_PODCAST_ALL "'/>"
+  "     <separator name='podcasts-4'/>"
+  "     <menu action='" POD_ACTION_SORT_BY "'>"
+  "     	<menuitem action='" POD_ACTION_SORT_BY_NAME "'/>"
+  "     	<menuitem action='" POD_ACTION_SORT_BY_DATE "'/>"
+  "	</menu>"
   "   </menu>"
   "   </placeholder>"
   "</menubar>"
@@ -132,20 +140,32 @@ namespace
   std::string
   get_timestr_from_time_t (time_t atime)
   {
-    struct tm atm;
+    struct tm atm, btm;
     localtime_r (&atime, &atm);
-
-    char bdate[64];
-    strftime (bdate, 64, "%d %b %Y", &atm);
-
-    char btime[64];
-
-    strftime (btime, 64, "%H:00", &atm); // we just ASSUME that no podcast updates more than once an hour, for cleaner readbility
+    time_t curtime = time(NULL);
+    localtime_r (&curtime, &btm);
 
     static boost::format
       date_f ("%s, %s");
 
-    return locale_to_utf8 ((date_f % bdate % btime).str());
+    if (atm.tm_year == btm.tm_year &&
+	atm.tm_yday == btm.tm_yday)
+    {
+	    char btime[64];
+	    strftime (btime, 64, "%H:00", &atm); // we just ASSUME that no podcast updates more than once an hour, for cleaner readbility
+
+    	    return locale_to_utf8 ((date_f % _("Today") % btime).str());
+    }
+    else
+    {
+	    char bdate[64];
+	    strftime (bdate, 64, "%d %b %Y", &atm);
+
+	    char btime[64];
+	    strftime (btime, 64, "%H:00", &atm); // we just ASSUME that no podcast updates more than once an hour, for cleaner readbility
+
+    	    return locale_to_utf8 ((date_f % bdate % btime).str());
+    }
   }
 
   std::string
@@ -175,10 +195,10 @@ namespace
   }
 
   static boost::format
-    podcast_title_f ("<b>%s</b>\n<small>%s</small>");
+    podcast_title_f N_("<b>%s</b>\n<small><i>%s</i></small> <span color='#ff0000'>%s</span>");
 
   static boost::format
-    podcast_descr_f ("<small>%s</small>");
+    podcast_descr_f N_("<small>%s</small>");
 }
 
 namespace Bmp
@@ -197,6 +217,7 @@ namespace Bmp
       m_actions = ActionGroup::create ("ActionsPodcasts");
       m_actions->add (Action::create ("dummy", "dummy"));
       m_actions->add (Action::create ("MenuUiPartPodcasts", _("Po_dcasts")));
+      m_actions->add (Action::create (POD_ACTION_SORT_BY, _("_Sort Podcasts By...")));
 
       m_actions->add (Action::create (POD_ACTION_ADD_PODCAST,
                                       StockID (BMP_STOCK_FEED_ADD),
@@ -235,6 +256,19 @@ namespace Bmp
                                       _("Export Feedlist (OPML Format)...")),
                                       AccelKey (""),
                                       sigc::mem_fun (*this, &UiPart::Podcasts::on_export_feedlist));
+ 
+      Gtk::RadioButtonGroup gr1;
+
+      m_actions->add (RadioAction::create (gr1, POD_ACTION_SORT_BY_NAME,
+                                      _("Name")),
+                                      sigc::mem_fun (*this, &UiPart::Podcasts::on_sorting_changed));
+
+      m_actions->add (RadioAction::create (gr1, POD_ACTION_SORT_BY_DATE,
+                                      _("Most Recent")),
+                                      sigc::mem_fun (*this, &UiPart::Podcasts::on_sorting_changed));
+
+      RefPtr<Gtk::RadioAction>::cast_static (m_actions->get_action (POD_ACTION_SORT_BY_NAME))->property_value() = 0; 
+      RefPtr<Gtk::RadioAction>::cast_static (m_actions->get_action (POD_ACTION_SORT_BY_DATE))->property_value() = 1; 
 
       m_ui_manager->insert_action_group (m_actions);
       m_ui_manager->add_ui_from_string (ui_string_casts_popup);
@@ -471,6 +505,13 @@ namespace Bmp
         update_all_cycle ();
     }
 
+    void
+    Podcasts::on_sorting_changed ()
+    {
+	CastData.Store->unset_default_sort_func ();
+        CastData.Store->set_default_sort_func (sigc::mem_fun (*this, &Bmp::UiPart::Podcasts::casts_default_sort_func));
+    }
+
     guint
     Podcasts::add_ui ()
     {
@@ -510,12 +551,14 @@ namespace Bmp
       if( cast.item_map.empty() )
       {
         title = ((podcast_title_f % Markup::escape_text (cast.podcast["title"]).c_str()
-                                  % _("(No Current Episodes)")).str());
+                                  % _("(No Current Episodes)")
+				  % (!cast.most_recent_is_played ? "*" : "")).str());
       }
       else
       {
         title = ((podcast_title_f % Markup::escape_text (cast.podcast["title"]).c_str()
-                                  % Markup::escape_text (get_timestr_from_time_t (cast.most_recent_item)).c_str()).str());
+                                  % Markup::escape_text (get_timestr_from_time_t (cast.most_recent_item)).c_str()
+				  % (!cast.most_recent_is_played ? "*" : "")).str());
       }
 
       casts_image_load (cast, iter);
@@ -557,12 +600,14 @@ namespace Bmp
       if( cast.item_map.empty() )
       {
         title = ((podcast_title_f % Markup::escape_text (cast.podcast["title"]).c_str()
-                                  % _("(No Current Episodes)")).str());
+                                  % _("(No Current Episodes)")
+				  % (!cast.most_recent_is_played ? "*" : "")).str());
       }
       else
       {
         title = ((podcast_title_f % Markup::escape_text (cast.podcast["title"]).c_str()
-                                  % Markup::escape_text (get_timestr_from_time_t (cast.most_recent_item)).c_str()).str());
+                                  % Markup::escape_text (get_timestr_from_time_t (cast.most_recent_item)).c_str()
+				  % (!cast.most_recent_is_played ? "*" : "")).str());
       }
 
       TreeIter iter = CastData.Store->append ();
@@ -864,6 +909,8 @@ namespace Bmp
           }
 
           case GTK_RESPONSE_CANCEL:
+	  case GTK_RESPONSE_CLOSE:
+	  case GTK_RESPONSE_DELETE_EVENT:
             return;
         }
       }
@@ -897,7 +944,7 @@ namespace Bmp
       catch (EpisodeInvalidError & cxe)
         {
           MessageDialog dialog (
-            _("This item can not be downloaded (malformed URI)"),
+            _("An Error occured: This has a malformed URI and can not be downloaded."),
             false, MESSAGE_ERROR, BUTTONS_OK, true);
           dialog.run ();
           return;
@@ -1050,10 +1097,30 @@ namespace Bmp
     int
     Podcasts::casts_default_sort_func (TreeIter const& iter_a, TreeIter const& iter_b)
     {
-      ustring t1 = (*iter_a)[CastData.ColumnRecord.searchtitle];
-      ustring t2 = (*iter_b)[CastData.ColumnRecord.searchtitle];
+      int active = RefPtr<Gtk::RadioAction>::cast_static (m_actions->get_action (POD_ACTION_SORT_BY_NAME))->get_current_value();
 
-      return t1.compare (t2);
+      if (active == 0)	
+      {
+	ustring t1 = (*iter_a)[CastData.ColumnRecord.searchtitle];
+	ustring t2 = (*iter_b)[CastData.ColumnRecord.searchtitle];
+	return t1.compare (t2);
+      }
+      else if (active == 1)
+      {     
+	time_t most_recent_1 = (*iter_a)[CastData.ColumnRecord.most_recent],
+	       most_recent_2 = (*iter_b)[CastData.ColumnRecord.most_recent];
+
+	if(most_recent_1 == most_recent_2)
+	  return 0;
+
+	if(most_recent_1 < most_recent_2)
+	  return 1;
+
+	if(most_recent_1 > most_recent_2)
+	  return -1;
+       }
+
+       g_assert_not_reached();
     }
 
     int
@@ -1320,6 +1387,29 @@ namespace Bmp
         m_caps = Caps (m_caps & ~PlaybackSource::CAN_PAUSE);
       }
 
+      // check to fix cast title/remove marker
+      if(StateData.Iter && StateData.Iter.get() == EpisodesData.Store->children().begin())
+      {
+	// FIXME: Account for filtering in the episodes store, NOT RELEVANT _YET_
+        TreeIter iter = (*mContextMap.find( StateData.CastUid )->second);
+        Podcast & cast = mPodcastManager->podcast_fetch ((*iter)[CastData.ColumnRecord.uri]);
+
+        if( cast.item_map.empty() )
+        {
+          (*iter)[CastData.ColumnRecord.title] =
+            ((podcast_title_f % Markup::escape_text (cast.podcast["title"]).c_str()
+	      			  % "" 
+                                  % _("(No Current Episodes)")).str());
+        }
+        else
+        {
+          (*iter)[CastData.ColumnRecord.title] = 
+	    ((podcast_title_f % Markup::escape_text (cast.podcast["title"]).c_str()
+				  % "" 
+                                  % Markup::escape_text (get_timestr_from_time_t (cast.most_recent_item)).c_str()).str());
+        }
+      }
+
       bool next, prev;
       has_next_prev (next, prev);
 
